##  Benefits
  * Maintain an up-to-date inventory of your landscape through automated discovery.
  * Easily understand and model the discoveries aligned with SAP best practices.
  * Identify and discover all SaaS, SAP on-premise cloud products and services, and SAP extensions.
  * Use catalogs to enrich fact sheets and ensure data completeness.
  * Evaluate and compare your SAP architecture based on business capabilities and criticality to pinpoint your starting point.
  * Plan your transformation knowing your current SAP landscape, including SAP extensions.
